# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import filer.fields.image
import fluent_contents.extensions


class Migration(migrations.Migration):

    dependencies = [
        ('filer', '0001_initial'),
        ('fluent_contents', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='FilerTeaserItem',
            fields=[
                ('contentitem_ptr', models.OneToOneField(parent_link=True, auto_created=True, primary_key=True, serialize=False, to='fluent_contents.ContentItem')),
                ('title', models.CharField(max_length=256, verbose_name='title')),
                ('url', fluent_contents.extensions.PluginUrlField(help_text='If present image will be clickable.', max_length=300, null=True, verbose_name='URL', blank=True)),
                ('description', models.TextField(null=True, verbose_name='description', blank=True)),
                ('target', models.CharField(blank=True, max_length=100, verbose_name='target', choices=[(b'', 'same window'), (b'_blank', 'new window'), (b'_parent', 'parent window'), (b'_top', 'topmost frame')])),
                ('image', filer.fields.image.FilerImageField(verbose_name='image', blank=True, to='filer.Image', null=True)),
            ],
            options={
                'db_table': 'contentitem_teaser_filerteaseritem',
                'verbose_name': 'Teaser',
                'verbose_name_plural': 'Teasers',
            },
            bases=('fluent_contents.contentitem',),
        ),
    ]



# -*- coding: utf-8 -*-

from future.builtins import str
from future.utils import python_2_unicode_compatible

from django.db import models
from django.utils.translation import ugettext_lazy as _

from filer.fields.image import FilerImageField

from fluent_contents.extensions import PluginUrlField
from fluent_contents.models.db import ContentItem


@python_2_unicode_compatible
class FilerPictureItem(ContentItem):
    ALIGN_LEFT = 'left'
    ALIGN_CENTER = 'center'
    ALIGN_RIGHT = 'right'
    ALIGN_CHOICES = (
        (ALIGN_LEFT, _("Left")),
        (ALIGN_CENTER, _("Center")),
        (ALIGN_RIGHT, _("Right")),
    )

    image = FilerImageField(verbose_name=_("image"))
    caption = models.TextField(_("caption"), blank=True)
    align = models.CharField(_("align"), max_length=10, choices=ALIGN_CHOICES, blank=True)

    url = PluginUrlField(_("URL"), blank=True)
    in_new_window = models.BooleanField(_("open in a new window"), default=False, blank=True)

    class Meta:
        verbose_name = _("Picture")
        verbose_name_plural = _("Pictures")

    def __str__(self):
        return self.caption or str(self.image)

    @property
    def align_class(self):
        if self.align == self.ALIGN_LEFT:
            return 'align-left'
        elif self.align == self.ALIGN_CENTER:
            return 'align-center'
        elif self.align == self.ALIGN_RIGHT:
            return 'align-right'
        else:
            return ''



# -*- coding: utf-8 -*-

from future.builtins import str
from future.utils import python_2_unicode_compatible

from django.db import models
from django.utils.translation import ugettext_lazy as _

from filer.fields.file import FilerFileField

from fluent_contents.models.db import ContentItem


@python_2_unicode_compatible
class FilerFileItem(ContentItem):

    file = FilerFileField(verbose_name=_("file"))
    name = models.CharField(_("name"), max_length=255, null=True, blank=True)

    target = models.CharField(_("target"), blank=True, max_length=100, choices=((
        ("", _("same window")),
        ("_blank", _("new window")),
        ("_parent", _("parent window")),
        ("_top", _("topmost frame")),
    )), default='')

    class Meta:
        verbose_name = _("File")
        verbose_name_plural = _("Files")

    @property
    def filename(self):
        if self.file.name in ('', None):
            return self.file.original_filename
        return self.file.name
    
    def __str__(self):
        if self.name:
            return self.name
        elif self.file:
            return str(self.filename)
        return "<empty>"



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import filer.fields.image
import fluent_contents.extensions


class Migration(migrations.Migration):

    dependencies = [
        ('filer', '0001_initial'),
        ('fluent_contents', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='FilerPictureItem',
            fields=[
                ('contentitem_ptr', models.OneToOneField(parent_link=True, auto_created=True, primary_key=True, serialize=False, to='fluent_contents.ContentItem')),
                ('caption', models.TextField(verbose_name='caption', blank=True)),
                ('align', models.CharField(blank=True, max_length=10, verbose_name='align', choices=[(b'left', 'Left'), (b'center', 'Center'), (b'right', 'Right')])),
                ('url', fluent_contents.extensions.PluginUrlField(max_length=300, verbose_name='URL', blank=True)),
                ('in_new_window', models.BooleanField(default=False, verbose_name='open in a new window')),
                ('image', filer.fields.image.FilerImageField(verbose_name='image', to='filer.Image')),
            ],
            options={
                'db_table': 'contentitem_picture_filerpictureitem',
                'verbose_name': 'Picture',
                'verbose_name_plural': 'Pictures',
            },
            bases=('fluent_contents.contentitem',),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import filer.fields.file


class Migration(migrations.Migration):

    dependencies = [
        ('filer', '0001_initial'),
        ('fluent_contents', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='FilerFileItem',
            fields=[
                ('contentitem_ptr', models.OneToOneField(parent_link=True, auto_created=True, primary_key=True, serialize=False, to='fluent_contents.ContentItem')),
                ('name', models.CharField(max_length=255, null=True, verbose_name='name', blank=True)),
                ('target', models.CharField(default=b'', max_length=100, verbose_name='target', blank=True, choices=[(b'', 'same window'), (b'_blank', 'new window'), (b'_parent', 'parent window'), (b'_top', 'topmost frame')])),
                ('file', filer.fields.file.FilerFileField(verbose_name='file', to='filer.File')),
            ],
            options={
                'db_table': 'contentitem_file_filerfileitem',
                'verbose_name': 'File',
                'verbose_name_plural': 'Files',
            },
            bases=('fluent_contents.contentitem',),
        ),
    ]



# -*- coding: utf-8 -*-

from future.utils import python_2_unicode_compatible

from django.db import models
from django.utils.translation import ugettext_lazy as _

from filer.fields.image import FilerImageField

from fluent_contents.extensions import PluginUrlField
from fluent_contents.models.db import ContentItem


@python_2_unicode_compatible
class FilerTeaserItem(ContentItem):

    title = models.CharField(_("title"), max_length=256)
    image = FilerImageField(verbose_name=_("image"), blank=True, null=True)
    url = PluginUrlField(_("URL"), null=True, blank=True,
        help_text=_("If present image will be clickable."))

    description = models.TextField(_("description"), blank=True, null=True)

    target = models.CharField(_("target"), blank=True, max_length=100, choices=((
        ("", _("same window")),
        ("_blank", _("new window")),
        ("_parent", _("parent window")),
        ("_top", _("topmost frame")),
    )))

    class Meta:
        verbose_name = _("Teaser")
        verbose_name_plural = _("Teasers")

    def __str__(self):
        return self.title



# -*- coding: utf-8 -*-

from django.utils.translation import ugettext_lazy as _

from fluent_contents.extensions import ContentPlugin, plugin_pool

from .models import FilerTeaserItem


@plugin_pool.register
class FilerTeaserPlugin(ContentPlugin):
    model = FilerTeaserItem
    category = _('Filer')
    render_template = "fluentcms_filer/teaser.html"



# -*- coding: utf-8 -*-

from django.utils.translation import ugettext_lazy as _
from django.contrib.admin.widgets import AdminTextareaWidget

from fluent_contents.extensions import ContentPlugin, plugin_pool

from .models import FilerPictureItem


@plugin_pool.register
class FilerPicturePlugin(ContentPlugin):
    model = FilerPictureItem
    category = _('Filer')
    render_template = "fluentcms_filer/picture.html"

    formfield_overrides = {
        'caption': {
            'widget': AdminTextareaWidget(attrs={'cols': 30, 'rows': 4, 'class': 'vTextField'}),
        },
    }
    radio_fields = {
        'align': ContentPlugin.HORIZONTAL
    }

    class Media:
        css = {
            'screen': (
                'fluentcms_filer/picture/admin.css',
            )
        }    



#!/usr/bin/env python

import os
import re
import sys
import codecs

from setuptools import setup, find_packages

# When creating the sdist, make sure the django.mo file also exists:
if 'sdist' in sys.argv or 'develop' in sys.argv:
    os.chdir('fluentcms_filer')

    for plugin in ['file', 'picture', 'teaser']:
        os.chdir(plugin)
        try:
            from django.core.management.commands.compilemessages import Command
            command = Command()
            command.execute(stdout=sys.stderr, exclude=[], verbosity=1)
        except ImportError:
            # < Django 1.7
            from django.core.management.commands.compilemessages import compile_messages
            compile_messages(sys.stderr, exclude=[])
        finally:
            os.chdir('..')

    os.chdir('..')


def read(*parts):
    file_path = os.path.join(os.path.dirname(__file__), *parts)
    return codecs.open(file_path, encoding='utf-8').read()


def find_version(*parts):
    version_file = read(*parts)
    version_match = re.search(r"^__version__ = ['\"]([^'\"]*)['\"]", version_file, re.M)
    if version_match:
        return str(version_match.group(1))
    raise RuntimeError("Unable to find version string.")


setup(
    name='fluentcms-filer',
    version=find_version('fluentcms_filer', '__init__.py'),
    license='Apache License, Version 2.0',

    install_requires=[
        'django-fluent-contents>=1.0',
        'django-filer>=0.9',
    ],
    requires=[
        'Django (>=1.4)',
    ],

    description='django-filer content plugins for django-fluent-pages',
    long_description=read('README.rst'),

    author='Basil Shubin',
    author_email='basil.shubin@gmail.com',

    url='https://github.com/bashu/fluentcms-filer',
    download_url='https://github.com/bashu/fluentcms-filer/zipball/master',

    packages=find_packages(exclude=('example*',)),
    include_package_data=True,

    zip_safe=False,
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ]
)
